const webpack = require("webpack");
const merge = require("webpack-merge");
const path = require("path");
const UglifyJsPlugin = require("uglifyjs-webpack-plugin");

const { VueLoaderPlugin } = require("vue-loader");

var config = {
    plugins: [new VueLoaderPlugin()],
    output: {
        path: path.resolve(__dirname + "/dist/")
    },
    module: {
        rules: [
            {
                test: /\.js$/,
                loader: "babel-loader",
                include: __dirname,
                exclude: /node_modules/
            },
            {
                test: /\.vue$/,
                loader: "vue-loader"
            },
            {
                test: /\.css$/,
                use: ["vue-style-loader", "css-loader"]
            }
        ]
    },
    optimization: {
        minimizer: [
            new UglifyJsPlugin({
                cache: true,
                parallel: true,
                uglifyOptions: {
                    compress: false,
                    ecma: 6,
                    mangle: true
                },
                sourceMap: true
            })
        ]
    }
};

module.exports = [
    merge(config, {
        entry: path.resolve(__dirname + "/src/plugin.js"),
        output: {
            filename: "vue-lazy-loading-image.min.js",
            libraryTarget: "window",
            library: "VueLazyLoadingImage"
        }
    }),
    merge(config, {
        entry: path.resolve(__dirname + "/src/VueLazyLoadingImage.vue"),
        output: {
            filename: "vue-lazy-loading-image.js",
            libraryTarget: "umd",
            library: "vue-lazy-loading-image",
            umdNamedDefine: true
        }
    })
];
